#!/bin/sh
if [ -z $1 ]; then
	echo "Please specify a destination."
	exit 1
fi

date
scp vmm/vmm.elf bios/out/bios.bin $1

